@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2021 Damien Nguyen
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -15,6 +14,7 @@
 
 """Wrapper script for clang-tidy."""
 
+import logging
 import sys
 from pathlib import Path
 
@@ -53,6 +53,8 @@ class ClangTidyCmd(ClangAnalyzerCmd):
         else:
             result.stderr = ''
 
+        logging.debug('returncode %d', result.returncode)
+        logging.debug('parsing output from %s', result.stderr)
         return result.returncode != 0 or any(
             msg in result.stderr
             for msg in (
